@@ -27,6 +27,7 @@ from .type_defs import (
     DeleteResourcePolicyResponseTypeDef,
     DeleteSecretResponseTypeDef,
     DescribeSecretResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     FilterTypeDef,
     GetRandomPasswordResponseTypeDef,
     GetResourcePolicyResponseTypeDef,
@@ -336,7 +337,9 @@ class SecretsManagerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#stop_replication_to_replica)
         """
 
-    def tag_resource(self, *, SecretId: str, Tags: Sequence[TagTypeDef]) -> None:
+    def tag_resource(
+        self, *, SecretId: str, Tags: Sequence[TagTypeDef]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Attaches tags to a secret.
 
@@ -344,7 +347,9 @@ class SecretsManagerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#tag_resource)
         """
 
-    def untag_resource(self, *, SecretId: str, TagKeys: Sequence[str]) -> None:
+    def untag_resource(
+        self, *, SecretId: str, TagKeys: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes specific tags from a secret.
 
